SystemOrganization addCategory: #'Seaside-Pharo-Email'!

!GRPackage class methodsFor: '*seaside-pharo-email' stamp: 'lr 2/17/2010 15:13'!
seasidePharoEmail
	^ self new
		name: 'Seaside-Pharo-Email';
		description: 'Pharo implementation classes for the package "Seaside-Email".';
		addDependency: 'Seaside-Email';
		addDependency: 'Seaside-Pharo-Core';
		url: #seasideUrl;
		yourself! !

!GRPharoPlatform methodsFor: '*seaside-pharo-email' stamp: 'pmm 2/25/2011 07:27'!
isIpAddress: aString
	| ip |
	ip := aString findTokens: '.'.
	^ ip size = 4
		and: [ ip allSatisfy: [ :each | each greaseInteger notNil
			and: [ each greaseInteger between: 0 and: 255] ] ]! !

!GRPharoPlatform methodsFor: '*seaside-pharo-email' stamp: 'lr 7/25/2011 18:36'!
seasideDeliverEmailMessage: aWAEmailMessage

	| client server serverAddress |
	client := SMTPClient new.
	"user login information if applicable"
	self seasideSmtpUsername ifNotNilDo: [ :username | 
		client user: username.
		self seasideSmtpPassword ifNotNilDo: [ :password |
			client password: password ] ].
	"use HELO/EHLO ip address format [127.0.0.1] if local host name is ip"
	(self isIpAddress: client localHostName) 
		ifTrue: [ client localHostName: '[', client localHostName, ']' ].

	"deliver the mail"
	server := self seasideSmtpServer.
	serverAddress := (self isIpAddress: server)
		ifTrue: [ server ] 
		ifFalse: [ NetNameResolver addressForName: server ].
	client openOnHost: serverAddress port: self seasideSmtpPort.
	[ client 
		mailFrom: aWAEmailMessage from greaseString 
		to: aWAEmailMessage recipientsAddresses
		text: aWAEmailMessage plainMessage.
	client quit ]
		ensure: [ client close ]
! !

!GRPharoPlatform methodsFor: '*seaside-pharo-email' stamp: 'pmm 6/19/2011 16:31'!
seasideSmtpPassword

	^ self seasideHandlerPreferenceAt: #smtpPassword ifAbsent: [ nil ]! !

!GRPharoPlatform methodsFor: '*seaside-pharo-email' stamp: 'pmm 6/19/2011 16:31'!
seasideSmtpPort

	^ self seasideHandlerPreferenceAt: #smtpPort ifAbsent: [ SMTPClient defaultPortNumber ]! !

!GRPharoPlatform methodsFor: '*seaside-pharo-email' stamp: 'pmm 6/19/2011 16:31'!
seasideSmtpServer

	^ self seasideHandlerPreferenceAt: #smtpServer ifAbsent: [ MailSender smtpServer ]! !

!GRPharoPlatform methodsFor: '*seaside-pharo-email' stamp: 'pmm 6/19/2011 16:31'!
seasideSmtpUsername

	^ self seasideHandlerPreferenceAt: #smtpUsername ifAbsent: [ nil ]! !

WAErrorHandler subclass: #WAEmailErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Pharo-Email'!

!WAEmailErrorHandler commentStamp: 'pmm 9/14/2008 17:06' prior: 0!
A WAEmailErrorHandler is an error handler that sends out email messages with the stack strace. This is an abstract class that has to be subclassed. Subclasses must override #to and #from that return an instance of WAEmailAddress. It's also recommened to override #handleDefault: to generate a custom HTML response.
!

!WAEmailErrorHandler methodsFor: 'private' stamp: 'lr 7/25/2011 20:00'!
bodyFor: anError
	^ WAStringEmailBody string: (String streamContents: [ :stream | 
		anError signalerContext errorReportOn: stream ])! !

!WAEmailErrorHandler methodsFor: 'private' stamp: 'pmm 9/14/2008 14:55'!
from
	"ansers the WAEmailAddress instance used as a sender addresst"
	self subclassResponsibility! !

!WAEmailErrorHandler methodsFor: 'actions' stamp: 'lr 7/25/2011 20:00'!
handleError: anException
	self sendFailFor: anException.
	^ super handleError: anException! !

!WAEmailErrorHandler methodsFor: 'private' stamp: 'pmm 9/14/2008 14:48'!
sendFailFor: anError
	| message |
	message := WAEmailMessage
		from: self from
		to: self to
		subject: (self subjectFor: anError).
	message body: (self bodyFor: anError).
	message send! !

!WAEmailErrorHandler methodsFor: 'private' stamp: 'lr 7/25/2011 20:00'!
subjectFor: anError
	^ anError signalerContext printString! !

!WAEmailErrorHandler methodsFor: 'private' stamp: 'pmm 9/14/2008 14:54'!
to
	"ansers the WAEmailAddress instance to which the error mail should be sent"
	self subclassResponsibility! !
